Hypex’s GUI theme and helpers, built around egui.
Re-exports
pub use icons::Icon;
Modules
- egui_
helpers - icons
- toasts
- A toast notification system for egui, roughly based on https://github.com/urholaukkarinen/egui-toast.
Structs
- Design
Tokens - The look and feel of the UI.
- HypexUi
- Layout
JobBuilder - Utility for building layout jobs.
- Static
Image Cache - TopBar
Style
Constants
- CUSTOM_
WINDOW_ DECORATIONS - If true, we hide the native window decoration (the top bar with app title, close button etc), and instead paint our own close/maximize/minimize buttons.
- FULLSIZE_
CONTENT - If true, we fill the entire window, except for the close/maximize/minimize buttons in the top-left. See https://github.com/emilk/egui/pull/2049
- NATIVE_
WINDOW_ BAR - If true, we show the native window decorations/chrome with the close/maximize/minimize buttons and app title.
Functions
- help_
hover_ button - native_
window_ buttons_ ui - Show some close/maximize/minimize buttons for the native window.
- toggle_
switch - iOS-style toggle switch.